module Tests exposing (..)

import Expect exposing (Expectation)
import Fuzz exposing (Fuzzer, list, int, string)
import Test exposing (..)
import Date exposing (Date, Month(..))
import Date.Extra as Date
import Easter exposing (EasterMethod(..))


all : Test
all =
    describe "Easter tests"
        [ suite "Julian" Julian julianEasters
        , suite "Orthodox" Orthodox orthodoxEasters
        , suite "Western" Western westernEasters
        ]


suite : String -> EasterMethod -> List Date -> Test
suite methodName method easters =
    describe (methodName ++ " easters") <|
        List.map (genTest method) easters


genTest : EasterMethod -> Date -> Test
genTest method date =
    let
        year =
            Date.year date
    in
        test (toString year) <|
            \() -> (Expect.equal (Easter.easter method year) date)


julianEasters =
    [ Date.fromCalendarDate 1200 Apr 9
    , Date.fromCalendarDate 1201 Mar 25
    , Date.fromCalendarDate 1202 Apr 14
    , Date.fromCalendarDate 1203 Apr 6
    , Date.fromCalendarDate 1204 Apr 25
    , Date.fromCalendarDate 1205 Apr 10
    , Date.fromCalendarDate 1206 Apr 2
    , Date.fromCalendarDate 1207 Apr 22
    , Date.fromCalendarDate 1208 Apr 6
    , Date.fromCalendarDate 1209 Mar 29
    , Date.fromCalendarDate 1210 Apr 18
    , Date.fromCalendarDate 1211 Apr 3
    , Date.fromCalendarDate 1212 Mar 25
    , Date.fromCalendarDate 1213 Apr 14
    , Date.fromCalendarDate 1214 Mar 30
    , Date.fromCalendarDate 1215 Apr 19
    , Date.fromCalendarDate 1216 Apr 10
    , Date.fromCalendarDate 1217 Mar 26
    , Date.fromCalendarDate 1218 Apr 15
    , Date.fromCalendarDate 1219 Apr 7
    , Date.fromCalendarDate 1220 Mar 29
    , Date.fromCalendarDate 1221 Apr 11
    , Date.fromCalendarDate 1222 Apr 3
    , Date.fromCalendarDate 1223 Apr 23
    , Date.fromCalendarDate 1224 Apr 14
    , Date.fromCalendarDate 1225 Mar 30
    , Date.fromCalendarDate 1226 Apr 19
    , Date.fromCalendarDate 1227 Apr 11
    , Date.fromCalendarDate 1228 Mar 26
    , Date.fromCalendarDate 1229 Apr 15
    , Date.fromCalendarDate 1230 Apr 7
    , Date.fromCalendarDate 1231 Mar 23
    , Date.fromCalendarDate 1232 Apr 11
    , Date.fromCalendarDate 1233 Apr 3
    , Date.fromCalendarDate 1234 Apr 23
    , Date.fromCalendarDate 1235 Apr 8
    , Date.fromCalendarDate 1236 Mar 30
    , Date.fromCalendarDate 1237 Apr 19
    , Date.fromCalendarDate 1238 Apr 4
    , Date.fromCalendarDate 1239 Mar 27
    , Date.fromCalendarDate 1240 Apr 15
    , Date.fromCalendarDate 1241 Mar 31
    , Date.fromCalendarDate 1242 Apr 20
    , Date.fromCalendarDate 1243 Apr 12
    , Date.fromCalendarDate 1244 Apr 3
    , Date.fromCalendarDate 1245 Apr 16
    , Date.fromCalendarDate 1246 Apr 8
    , Date.fromCalendarDate 1247 Mar 31
    , Date.fromCalendarDate 1248 Apr 19
    , Date.fromCalendarDate 1249 Apr 4
    , Date.fromCalendarDate 1250 Mar 27
    , Date.fromCalendarDate 1251 Apr 16
    , Date.fromCalendarDate 1252 Mar 31
    , Date.fromCalendarDate 1253 Apr 20
    , Date.fromCalendarDate 1254 Apr 12
    , Date.fromCalendarDate 1255 Mar 28
    , Date.fromCalendarDate 1256 Apr 16
    , Date.fromCalendarDate 1257 Apr 8
    , Date.fromCalendarDate 1258 Mar 24
    , Date.fromCalendarDate 1259 Apr 13
    , Date.fromCalendarDate 1260 Apr 4
    , Date.fromCalendarDate 1261 Apr 24
    , Date.fromCalendarDate 1262 Apr 9
    , Date.fromCalendarDate 1263 Apr 1
    , Date.fromCalendarDate 1264 Apr 20
    , Date.fromCalendarDate 1265 Apr 5
    , Date.fromCalendarDate 1266 Mar 28
    , Date.fromCalendarDate 1267 Apr 17
    , Date.fromCalendarDate 1268 Apr 8
    , Date.fromCalendarDate 1269 Mar 24
    , Date.fromCalendarDate 1270 Apr 13
    , Date.fromCalendarDate 1271 Apr 5
    , Date.fromCalendarDate 1272 Apr 24
    , Date.fromCalendarDate 1273 Apr 9
    , Date.fromCalendarDate 1274 Apr 1
    , Date.fromCalendarDate 1275 Apr 14
    , Date.fromCalendarDate 1276 Apr 5
    , Date.fromCalendarDate 1277 Mar 28
    , Date.fromCalendarDate 1278 Apr 17
    , Date.fromCalendarDate 1279 Apr 2
    , Date.fromCalendarDate 1280 Apr 21
    , Date.fromCalendarDate 1281 Apr 13
    , Date.fromCalendarDate 1282 Mar 29
    , Date.fromCalendarDate 1283 Apr 18
    , Date.fromCalendarDate 1284 Apr 9
    , Date.fromCalendarDate 1285 Mar 25
    , Date.fromCalendarDate 1286 Apr 14
    , Date.fromCalendarDate 1287 Apr 6
    , Date.fromCalendarDate 1288 Mar 28
    , Date.fromCalendarDate 1289 Apr 10
    , Date.fromCalendarDate 1290 Apr 2
    , Date.fromCalendarDate 1291 Apr 22
    , Date.fromCalendarDate 1292 Apr 6
    , Date.fromCalendarDate 1293 Mar 29
    , Date.fromCalendarDate 1294 Apr 18
    , Date.fromCalendarDate 1295 Apr 3
    , Date.fromCalendarDate 1296 Mar 25
    , Date.fromCalendarDate 1297 Apr 14
    , Date.fromCalendarDate 1298 Apr 6
    , Date.fromCalendarDate 1299 Apr 19
    , Date.fromCalendarDate 1300 Apr 10
    , Date.fromCalendarDate 1700 Mar 31
    , Date.fromCalendarDate 1701 Apr 20
    , Date.fromCalendarDate 1702 Apr 5
    , Date.fromCalendarDate 1703 Mar 28
    , Date.fromCalendarDate 1704 Apr 16
    , Date.fromCalendarDate 1705 Apr 8
    , Date.fromCalendarDate 1706 Mar 24
    , Date.fromCalendarDate 1707 Apr 13
    , Date.fromCalendarDate 1708 Apr 4
    , Date.fromCalendarDate 1709 Apr 24
    , Date.fromCalendarDate 1710 Apr 9
    , Date.fromCalendarDate 1711 Apr 1
    , Date.fromCalendarDate 1712 Apr 20
    , Date.fromCalendarDate 1713 Apr 5
    , Date.fromCalendarDate 1714 Mar 28
    , Date.fromCalendarDate 1715 Apr 17
    , Date.fromCalendarDate 1716 Apr 1
    , Date.fromCalendarDate 1717 Apr 21
    , Date.fromCalendarDate 1718 Apr 13
    , Date.fromCalendarDate 1719 Mar 29
    , Date.fromCalendarDate 1720 Apr 17
    , Date.fromCalendarDate 1721 Apr 9
    , Date.fromCalendarDate 1722 Mar 25
    , Date.fromCalendarDate 1723 Apr 14
    , Date.fromCalendarDate 1724 Apr 5
    , Date.fromCalendarDate 1725 Mar 28
    , Date.fromCalendarDate 1726 Apr 10
    , Date.fromCalendarDate 1727 Apr 2
    , Date.fromCalendarDate 1728 Apr 21
    , Date.fromCalendarDate 1729 Apr 6
    , Date.fromCalendarDate 1730 Mar 29
    , Date.fromCalendarDate 1731 Apr 18
    , Date.fromCalendarDate 1732 Apr 9
    , Date.fromCalendarDate 1733 Mar 25
    , Date.fromCalendarDate 1734 Apr 14
    , Date.fromCalendarDate 1735 Apr 6
    , Date.fromCalendarDate 1736 Apr 25
    , Date.fromCalendarDate 1737 Apr 10
    , Date.fromCalendarDate 1738 Apr 2
    , Date.fromCalendarDate 1739 Apr 22
    , Date.fromCalendarDate 1740 Apr 6
    , Date.fromCalendarDate 1741 Mar 29
    , Date.fromCalendarDate 1742 Apr 18
    , Date.fromCalendarDate 1743 Apr 3
    , Date.fromCalendarDate 1744 Mar 25
    , Date.fromCalendarDate 1745 Apr 14
    , Date.fromCalendarDate 1746 Mar 30
    , Date.fromCalendarDate 1747 Apr 19
    , Date.fromCalendarDate 1748 Apr 10
    , Date.fromCalendarDate 1749 Mar 26
    , Date.fromCalendarDate 1750 Apr 15
    , Date.fromCalendarDate 1751 Apr 7
    , Date.fromCalendarDate 1752 Mar 29
    , Date.fromCalendarDate 1753 Apr 11
    , Date.fromCalendarDate 1754 Apr 3
    , Date.fromCalendarDate 1755 Apr 23
    , Date.fromCalendarDate 1756 Apr 14
    , Date.fromCalendarDate 1757 Mar 30
    , Date.fromCalendarDate 1758 Apr 19
    , Date.fromCalendarDate 1759 Apr 11
    , Date.fromCalendarDate 1760 Mar 26
    , Date.fromCalendarDate 1761 Apr 15
    , Date.fromCalendarDate 1762 Apr 7
    , Date.fromCalendarDate 1763 Mar 23
    , Date.fromCalendarDate 1764 Apr 11
    , Date.fromCalendarDate 1765 Apr 3
    , Date.fromCalendarDate 1766 Apr 23
    , Date.fromCalendarDate 1767 Apr 8
    , Date.fromCalendarDate 1768 Mar 30
    , Date.fromCalendarDate 1769 Apr 19
    , Date.fromCalendarDate 1770 Apr 4
    , Date.fromCalendarDate 1771 Mar 27
    , Date.fromCalendarDate 1772 Apr 15
    , Date.fromCalendarDate 1773 Mar 31
    , Date.fromCalendarDate 1774 Apr 20
    , Date.fromCalendarDate 1775 Apr 12
    , Date.fromCalendarDate 1776 Apr 3
    , Date.fromCalendarDate 1777 Apr 16
    , Date.fromCalendarDate 1778 Apr 8
    , Date.fromCalendarDate 1779 Mar 31
    , Date.fromCalendarDate 1780 Apr 19
    , Date.fromCalendarDate 1781 Apr 4
    , Date.fromCalendarDate 1782 Mar 27
    , Date.fromCalendarDate 1783 Apr 16
    , Date.fromCalendarDate 1784 Mar 31
    , Date.fromCalendarDate 1785 Apr 20
    , Date.fromCalendarDate 1786 Apr 12
    , Date.fromCalendarDate 1787 Mar 28
    , Date.fromCalendarDate 1788 Apr 16
    , Date.fromCalendarDate 1789 Apr 8
    , Date.fromCalendarDate 1790 Mar 24
    , Date.fromCalendarDate 1791 Apr 13
    , Date.fromCalendarDate 1792 Apr 4
    , Date.fromCalendarDate 1793 Apr 24
    , Date.fromCalendarDate 1794 Apr 9
    , Date.fromCalendarDate 1795 Apr 1
    , Date.fromCalendarDate 1796 Apr 20
    , Date.fromCalendarDate 1797 Apr 5
    , Date.fromCalendarDate 1798 Mar 28
    , Date.fromCalendarDate 1799 Apr 17
    , Date.fromCalendarDate 1800 Apr 8
    , Date.fromCalendarDate 1801 Mar 24
    , Date.fromCalendarDate 1802 Apr 13
    , Date.fromCalendarDate 1803 Apr 5
    , Date.fromCalendarDate 1804 Apr 24
    , Date.fromCalendarDate 1805 Apr 9
    , Date.fromCalendarDate 1806 Apr 1
    , Date.fromCalendarDate 1807 Apr 14
    , Date.fromCalendarDate 1808 Apr 5
    , Date.fromCalendarDate 1809 Mar 28
    , Date.fromCalendarDate 1810 Apr 17
    , Date.fromCalendarDate 1811 Apr 2
    , Date.fromCalendarDate 1812 Apr 21
    , Date.fromCalendarDate 1813 Apr 13
    , Date.fromCalendarDate 1814 Mar 29
    , Date.fromCalendarDate 1815 Apr 18
    , Date.fromCalendarDate 1816 Apr 9
    , Date.fromCalendarDate 1817 Mar 25
    , Date.fromCalendarDate 1818 Apr 14
    , Date.fromCalendarDate 1819 Apr 6
    , Date.fromCalendarDate 1820 Mar 28
    , Date.fromCalendarDate 1821 Apr 10
    , Date.fromCalendarDate 1822 Apr 2
    , Date.fromCalendarDate 1823 Apr 22
    , Date.fromCalendarDate 1824 Apr 6
    , Date.fromCalendarDate 1825 Mar 29
    , Date.fromCalendarDate 1826 Apr 18
    , Date.fromCalendarDate 1827 Apr 3
    , Date.fromCalendarDate 1828 Mar 25
    , Date.fromCalendarDate 1829 Apr 14
    , Date.fromCalendarDate 1830 Apr 6
    , Date.fromCalendarDate 1831 Apr 19
    , Date.fromCalendarDate 1832 Apr 10
    , Date.fromCalendarDate 1833 Apr 2
    , Date.fromCalendarDate 1834 Apr 22
    , Date.fromCalendarDate 1835 Apr 7
    , Date.fromCalendarDate 1836 Mar 29
    , Date.fromCalendarDate 1837 Apr 18
    , Date.fromCalendarDate 1838 Apr 3
    , Date.fromCalendarDate 1839 Mar 26
    , Date.fromCalendarDate 1840 Apr 14
    , Date.fromCalendarDate 1841 Mar 30
    , Date.fromCalendarDate 1842 Apr 19
    , Date.fromCalendarDate 1843 Apr 11
    , Date.fromCalendarDate 1844 Mar 26
    , Date.fromCalendarDate 1845 Apr 15
    , Date.fromCalendarDate 1846 Apr 7
    , Date.fromCalendarDate 1847 Mar 23
    , Date.fromCalendarDate 1848 Apr 11
    , Date.fromCalendarDate 1849 Apr 3
    , Date.fromCalendarDate 1850 Apr 23
    , Date.fromCalendarDate 1920 Mar 29
    , Date.fromCalendarDate 1921 Apr 18
    , Date.fromCalendarDate 1922 Apr 3
    , Date.fromCalendarDate 1923 Mar 26
    , Date.fromCalendarDate 1924 Apr 14
    , Date.fromCalendarDate 1925 Apr 6
    , Date.fromCalendarDate 1926 Apr 19
    , Date.fromCalendarDate 1927 Apr 11
    , Date.fromCalendarDate 1928 Apr 2
    , Date.fromCalendarDate 1929 Apr 22
    , Date.fromCalendarDate 1930 Apr 7
    , Date.fromCalendarDate 1931 Mar 30
    , Date.fromCalendarDate 1932 Apr 18
    , Date.fromCalendarDate 1933 Apr 3
    , Date.fromCalendarDate 1934 Mar 26
    , Date.fromCalendarDate 1935 Apr 15
    , Date.fromCalendarDate 1936 Mar 30
    , Date.fromCalendarDate 1937 Apr 19
    , Date.fromCalendarDate 1938 Apr 11
    , Date.fromCalendarDate 1939 Mar 27
    , Date.fromCalendarDate 1940 Apr 15
    , Date.fromCalendarDate 1941 Apr 7
    , Date.fromCalendarDate 1942 Mar 23
    , Date.fromCalendarDate 1943 Apr 12
    , Date.fromCalendarDate 1944 Apr 3
    , Date.fromCalendarDate 1945 Apr 23
    , Date.fromCalendarDate 1946 Apr 8
    , Date.fromCalendarDate 1947 Mar 31
    , Date.fromCalendarDate 1948 Apr 19
    , Date.fromCalendarDate 1949 Apr 11
    , Date.fromCalendarDate 1950 Mar 27
    , Date.fromCalendarDate 1951 Apr 16
    , Date.fromCalendarDate 1952 Apr 7
    , Date.fromCalendarDate 1953 Mar 23
    , Date.fromCalendarDate 1954 Apr 12
    , Date.fromCalendarDate 1955 Apr 4
    , Date.fromCalendarDate 1956 Apr 23
    , Date.fromCalendarDate 1957 Apr 8
    , Date.fromCalendarDate 1958 Mar 31
    , Date.fromCalendarDate 1959 Apr 20
    , Date.fromCalendarDate 1960 Apr 4
    , Date.fromCalendarDate 1961 Mar 27
    , Date.fromCalendarDate 1962 Apr 16
    , Date.fromCalendarDate 1963 Apr 1
    , Date.fromCalendarDate 1964 Apr 20
    , Date.fromCalendarDate 1965 Apr 12
    , Date.fromCalendarDate 1966 Mar 28
    , Date.fromCalendarDate 1967 Apr 17
    , Date.fromCalendarDate 1968 Apr 8
    , Date.fromCalendarDate 1969 Mar 31
    , Date.fromCalendarDate 1970 Apr 13
    , Date.fromCalendarDate 1971 Apr 5
    , Date.fromCalendarDate 1972 Mar 27
    , Date.fromCalendarDate 1973 Apr 16
    , Date.fromCalendarDate 1974 Apr 1
    , Date.fromCalendarDate 1975 Apr 21
    , Date.fromCalendarDate 1976 Apr 12
    , Date.fromCalendarDate 1977 Mar 28
    , Date.fromCalendarDate 1978 Apr 17
    , Date.fromCalendarDate 1979 Apr 9
    , Date.fromCalendarDate 1980 Mar 24
    , Date.fromCalendarDate 1981 Apr 13
    , Date.fromCalendarDate 1982 Apr 5
    , Date.fromCalendarDate 1983 Apr 25
    , Date.fromCalendarDate 1984 Apr 9
    , Date.fromCalendarDate 1985 Apr 1
    , Date.fromCalendarDate 1986 Apr 21
    , Date.fromCalendarDate 1987 Apr 6
    , Date.fromCalendarDate 1988 Mar 28
    , Date.fromCalendarDate 1989 Apr 17
    , Date.fromCalendarDate 1990 Apr 2
    , Date.fromCalendarDate 1991 Mar 25
    , Date.fromCalendarDate 1992 Apr 13
    , Date.fromCalendarDate 1993 Apr 5
    , Date.fromCalendarDate 1994 Apr 18
    , Date.fromCalendarDate 1995 Apr 10
    , Date.fromCalendarDate 1996 Apr 1
    , Date.fromCalendarDate 1997 Apr 14
    , Date.fromCalendarDate 1998 Apr 6
    , Date.fromCalendarDate 1999 Mar 29
    , Date.fromCalendarDate 2000 Apr 17
    , Date.fromCalendarDate 2001 Apr 2
    , Date.fromCalendarDate 2002 Apr 22
    , Date.fromCalendarDate 2003 Apr 14
    , Date.fromCalendarDate 2004 Mar 29
    , Date.fromCalendarDate 2005 Apr 18
    , Date.fromCalendarDate 2006 Apr 10
    , Date.fromCalendarDate 2007 Mar 26
    , Date.fromCalendarDate 2008 Apr 14
    , Date.fromCalendarDate 2009 Apr 6
    , Date.fromCalendarDate 2010 Mar 22
    , Date.fromCalendarDate 2011 Apr 11
    , Date.fromCalendarDate 2012 Apr 2
    , Date.fromCalendarDate 2013 Apr 22
    , Date.fromCalendarDate 2014 Apr 7
    , Date.fromCalendarDate 2015 Mar 30
    , Date.fromCalendarDate 2016 Apr 18
    , Date.fromCalendarDate 2017 Apr 3
    , Date.fromCalendarDate 2018 Mar 26
    , Date.fromCalendarDate 2019 Apr 15
    , Date.fromCalendarDate 2020 Apr 6
    , Date.fromCalendarDate 2021 Apr 19
    , Date.fromCalendarDate 2022 Apr 11
    , Date.fromCalendarDate 2023 Apr 3
    , Date.fromCalendarDate 2024 Apr 22
    , Date.fromCalendarDate 2025 Apr 7
    , Date.fromCalendarDate 2026 Mar 30
    , Date.fromCalendarDate 2027 Apr 19
    , Date.fromCalendarDate 2028 Apr 3
    , Date.fromCalendarDate 2029 Mar 26
    , Date.fromCalendarDate 2030 Apr 15
    , Date.fromCalendarDate 2031 Mar 31
    , Date.fromCalendarDate 2032 Apr 19
    , Date.fromCalendarDate 2033 Apr 11
    , Date.fromCalendarDate 2034 Mar 27
    , Date.fromCalendarDate 2035 Apr 16
    , Date.fromCalendarDate 2036 Apr 7
    , Date.fromCalendarDate 2037 Mar 23
    , Date.fromCalendarDate 2038 Apr 12
    , Date.fromCalendarDate 2039 Apr 4
    , Date.fromCalendarDate 2040 Apr 23
    , Date.fromCalendarDate 2041 Apr 8
    , Date.fromCalendarDate 2042 Mar 31
    , Date.fromCalendarDate 2043 Apr 20
    , Date.fromCalendarDate 2044 Apr 11
    , Date.fromCalendarDate 2045 Mar 27
    , Date.fromCalendarDate 2046 Apr 16
    , Date.fromCalendarDate 2047 Apr 8
    , Date.fromCalendarDate 2048 Mar 23
    , Date.fromCalendarDate 2049 Apr 12
    , Date.fromCalendarDate 2050 Apr 4
    , Date.fromCalendarDate 2051 Apr 24
    , Date.fromCalendarDate 2052 Apr 8
    , Date.fromCalendarDate 2053 Mar 31
    , Date.fromCalendarDate 2054 Apr 20
    , Date.fromCalendarDate 2055 Apr 5
    , Date.fromCalendarDate 2056 Mar 27
    , Date.fromCalendarDate 2057 Apr 16
    , Date.fromCalendarDate 2058 Apr 1
    , Date.fromCalendarDate 2059 Apr 21
    , Date.fromCalendarDate 2060 Apr 12
    , Date.fromCalendarDate 2061 Mar 28
    , Date.fromCalendarDate 2062 Apr 17
    , Date.fromCalendarDate 2063 Apr 9
    , Date.fromCalendarDate 2064 Mar 31
    , Date.fromCalendarDate 2065 Apr 13
    , Date.fromCalendarDate 2066 Apr 5
    , Date.fromCalendarDate 2067 Mar 28
    , Date.fromCalendarDate 2068 Apr 16
    , Date.fromCalendarDate 2069 Apr 1
    , Date.fromCalendarDate 2070 Apr 21
    , Date.fromCalendarDate 2071 Apr 6
    , Date.fromCalendarDate 2072 Mar 28
    , Date.fromCalendarDate 2073 Apr 17
    , Date.fromCalendarDate 2074 Apr 9
    , Date.fromCalendarDate 2075 Mar 25
    , Date.fromCalendarDate 2076 Apr 13
    , Date.fromCalendarDate 2077 Apr 5
    , Date.fromCalendarDate 2078 Apr 25
    , Date.fromCalendarDate 2079 Apr 10
    , Date.fromCalendarDate 2080 Apr 1
    , Date.fromCalendarDate 2081 Apr 21
    , Date.fromCalendarDate 2082 Apr 6
    , Date.fromCalendarDate 2083 Mar 29
    , Date.fromCalendarDate 2084 Apr 17
    , Date.fromCalendarDate 2085 Apr 2
    , Date.fromCalendarDate 2086 Mar 25
    , Date.fromCalendarDate 2087 Apr 14
    , Date.fromCalendarDate 2088 Apr 5
    , Date.fromCalendarDate 2089 Apr 18
    , Date.fromCalendarDate 2090 Apr 10
    , Date.fromCalendarDate 2091 Mar 26
    , Date.fromCalendarDate 2092 Apr 14
    , Date.fromCalendarDate 2093 Apr 6
    , Date.fromCalendarDate 2094 Mar 29
    , Date.fromCalendarDate 2095 Apr 11
    , Date.fromCalendarDate 2096 Apr 2
    , Date.fromCalendarDate 2097 Apr 22
    , Date.fromCalendarDate 2098 Apr 14
    , Date.fromCalendarDate 2099 Mar 30
    , Date.fromCalendarDate 2100 Apr 18 ]


orthodoxEasters =
    [ Date.fromCalendarDate 1200 Apr 19
    , Date.fromCalendarDate 1201 Apr 4
    , Date.fromCalendarDate 1202 Apr 24
    , Date.fromCalendarDate 1203 Apr 16
    , Date.fromCalendarDate 1204 May 5
    , Date.fromCalendarDate 1205 Apr 20
    , Date.fromCalendarDate 1206 Apr 12
    , Date.fromCalendarDate 1207 May 2
    , Date.fromCalendarDate 1208 Apr 16
    , Date.fromCalendarDate 1209 Apr 8
    , Date.fromCalendarDate 1210 Apr 28
    , Date.fromCalendarDate 1211 Apr 13
    , Date.fromCalendarDate 1212 Apr 4
    , Date.fromCalendarDate 1213 Apr 24
    , Date.fromCalendarDate 1214 Apr 9
    , Date.fromCalendarDate 1215 Apr 29
    , Date.fromCalendarDate 1216 Apr 20
    , Date.fromCalendarDate 1217 Apr 5
    , Date.fromCalendarDate 1218 Apr 25
    , Date.fromCalendarDate 1219 Apr 17
    , Date.fromCalendarDate 1220 Apr 8
    , Date.fromCalendarDate 1221 Apr 21
    , Date.fromCalendarDate 1222 Apr 13
    , Date.fromCalendarDate 1223 May 3
    , Date.fromCalendarDate 1224 Apr 24
    , Date.fromCalendarDate 1225 Apr 9
    , Date.fromCalendarDate 1226 Apr 29
    , Date.fromCalendarDate 1227 Apr 21
    , Date.fromCalendarDate 1228 Apr 5
    , Date.fromCalendarDate 1229 Apr 25
    , Date.fromCalendarDate 1230 Apr 17
    , Date.fromCalendarDate 1231 Apr 2
    , Date.fromCalendarDate 1232 Apr 21
    , Date.fromCalendarDate 1233 Apr 13
    , Date.fromCalendarDate 1234 May 3
    , Date.fromCalendarDate 1235 Apr 18
    , Date.fromCalendarDate 1236 Apr 9
    , Date.fromCalendarDate 1237 Apr 29
    , Date.fromCalendarDate 1238 Apr 14
    , Date.fromCalendarDate 1239 Apr 6
    , Date.fromCalendarDate 1240 Apr 25
    , Date.fromCalendarDate 1241 Apr 10
    , Date.fromCalendarDate 1242 Apr 30
    , Date.fromCalendarDate 1243 Apr 22
    , Date.fromCalendarDate 1244 Apr 13
    , Date.fromCalendarDate 1245 Apr 26
    , Date.fromCalendarDate 1246 Apr 18
    , Date.fromCalendarDate 1247 Apr 10
    , Date.fromCalendarDate 1248 Apr 29
    , Date.fromCalendarDate 1249 Apr 14
    , Date.fromCalendarDate 1250 Apr 6
    , Date.fromCalendarDate 1251 Apr 26
    , Date.fromCalendarDate 1252 Apr 10
    , Date.fromCalendarDate 1253 Apr 30
    , Date.fromCalendarDate 1254 Apr 22
    , Date.fromCalendarDate 1255 Apr 7
    , Date.fromCalendarDate 1256 Apr 26
    , Date.fromCalendarDate 1257 Apr 18
    , Date.fromCalendarDate 1258 Apr 3
    , Date.fromCalendarDate 1259 Apr 23
    , Date.fromCalendarDate 1260 Apr 14
    , Date.fromCalendarDate 1261 May 4
    , Date.fromCalendarDate 1262 Apr 19
    , Date.fromCalendarDate 1263 Apr 11
    , Date.fromCalendarDate 1264 Apr 30
    , Date.fromCalendarDate 1265 Apr 15
    , Date.fromCalendarDate 1266 Apr 7
    , Date.fromCalendarDate 1267 Apr 27
    , Date.fromCalendarDate 1268 Apr 18
    , Date.fromCalendarDate 1269 Apr 3
    , Date.fromCalendarDate 1270 Apr 23
    , Date.fromCalendarDate 1271 Apr 15
    , Date.fromCalendarDate 1272 May 4
    , Date.fromCalendarDate 1273 Apr 19
    , Date.fromCalendarDate 1274 Apr 11
    , Date.fromCalendarDate 1275 Apr 24
    , Date.fromCalendarDate 1276 Apr 15
    , Date.fromCalendarDate 1277 Apr 7
    , Date.fromCalendarDate 1278 Apr 27
    , Date.fromCalendarDate 1279 Apr 12
    , Date.fromCalendarDate 1280 May 1
    , Date.fromCalendarDate 1281 Apr 23
    , Date.fromCalendarDate 1282 Apr 8
    , Date.fromCalendarDate 1283 Apr 28
    , Date.fromCalendarDate 1284 Apr 19
    , Date.fromCalendarDate 1285 Apr 4
    , Date.fromCalendarDate 1286 Apr 24
    , Date.fromCalendarDate 1287 Apr 16
    , Date.fromCalendarDate 1288 Apr 7
    , Date.fromCalendarDate 1289 Apr 20
    , Date.fromCalendarDate 1290 Apr 12
    , Date.fromCalendarDate 1291 May 2
    , Date.fromCalendarDate 1292 Apr 16
    , Date.fromCalendarDate 1293 Apr 8
    , Date.fromCalendarDate 1294 Apr 28
    , Date.fromCalendarDate 1295 Apr 13
    , Date.fromCalendarDate 1296 Apr 4
    , Date.fromCalendarDate 1297 Apr 24
    , Date.fromCalendarDate 1298 Apr 16
    , Date.fromCalendarDate 1299 Apr 29
    , Date.fromCalendarDate 1300 Apr 20
    , Date.fromCalendarDate 1700 Apr 11
    , Date.fromCalendarDate 1701 May 1
    , Date.fromCalendarDate 1702 Apr 16
    , Date.fromCalendarDate 1703 Apr 8
    , Date.fromCalendarDate 1704 Apr 27
    , Date.fromCalendarDate 1705 Apr 19
    , Date.fromCalendarDate 1706 Apr 4
    , Date.fromCalendarDate 1707 Apr 24
    , Date.fromCalendarDate 1708 Apr 15
    , Date.fromCalendarDate 1709 May 5
    , Date.fromCalendarDate 1710 Apr 20
    , Date.fromCalendarDate 1711 Apr 12
    , Date.fromCalendarDate 1712 May 1
    , Date.fromCalendarDate 1713 Apr 16
    , Date.fromCalendarDate 1714 Apr 8
    , Date.fromCalendarDate 1715 Apr 28
    , Date.fromCalendarDate 1716 Apr 12
    , Date.fromCalendarDate 1717 May 2
    , Date.fromCalendarDate 1718 Apr 24
    , Date.fromCalendarDate 1719 Apr 9
    , Date.fromCalendarDate 1720 Apr 28
    , Date.fromCalendarDate 1721 Apr 20
    , Date.fromCalendarDate 1722 Apr 5
    , Date.fromCalendarDate 1723 Apr 25
    , Date.fromCalendarDate 1724 Apr 16
    , Date.fromCalendarDate 1725 Apr 8
    , Date.fromCalendarDate 1726 Apr 21
    , Date.fromCalendarDate 1727 Apr 13
    , Date.fromCalendarDate 1728 May 2
    , Date.fromCalendarDate 1729 Apr 17
    , Date.fromCalendarDate 1730 Apr 9
    , Date.fromCalendarDate 1731 Apr 29
    , Date.fromCalendarDate 1732 Apr 20
    , Date.fromCalendarDate 1733 Apr 5
    , Date.fromCalendarDate 1734 Apr 25
    , Date.fromCalendarDate 1735 Apr 17
    , Date.fromCalendarDate 1736 May 6
    , Date.fromCalendarDate 1737 Apr 21
    , Date.fromCalendarDate 1738 Apr 13
    , Date.fromCalendarDate 1739 May 3
    , Date.fromCalendarDate 1740 Apr 17
    , Date.fromCalendarDate 1741 Apr 9
    , Date.fromCalendarDate 1742 Apr 29
    , Date.fromCalendarDate 1743 Apr 14
    , Date.fromCalendarDate 1744 Apr 5
    , Date.fromCalendarDate 1745 Apr 25
    , Date.fromCalendarDate 1746 Apr 10
    , Date.fromCalendarDate 1747 Apr 30
    , Date.fromCalendarDate 1748 Apr 21
    , Date.fromCalendarDate 1749 Apr 6
    , Date.fromCalendarDate 1750 Apr 26
    , Date.fromCalendarDate 1751 Apr 18
    , Date.fromCalendarDate 1752 Apr 9
    , Date.fromCalendarDate 1753 Apr 22
    , Date.fromCalendarDate 1754 Apr 14
    , Date.fromCalendarDate 1755 May 4
    , Date.fromCalendarDate 1756 Apr 25
    , Date.fromCalendarDate 1757 Apr 10
    , Date.fromCalendarDate 1758 Apr 30
    , Date.fromCalendarDate 1759 Apr 22
    , Date.fromCalendarDate 1760 Apr 6
    , Date.fromCalendarDate 1761 Apr 26
    , Date.fromCalendarDate 1762 Apr 18
    , Date.fromCalendarDate 1763 Apr 3
    , Date.fromCalendarDate 1764 Apr 22
    , Date.fromCalendarDate 1765 Apr 14
    , Date.fromCalendarDate 1766 May 4
    , Date.fromCalendarDate 1767 Apr 19
    , Date.fromCalendarDate 1768 Apr 10
    , Date.fromCalendarDate 1769 Apr 30
    , Date.fromCalendarDate 1770 Apr 15
    , Date.fromCalendarDate 1771 Apr 7
    , Date.fromCalendarDate 1772 Apr 26
    , Date.fromCalendarDate 1773 Apr 11
    , Date.fromCalendarDate 1774 May 1
    , Date.fromCalendarDate 1775 Apr 23
    , Date.fromCalendarDate 1776 Apr 14
    , Date.fromCalendarDate 1777 Apr 27
    , Date.fromCalendarDate 1778 Apr 19
    , Date.fromCalendarDate 1779 Apr 11
    , Date.fromCalendarDate 1780 Apr 30
    , Date.fromCalendarDate 1781 Apr 15
    , Date.fromCalendarDate 1782 Apr 7
    , Date.fromCalendarDate 1783 Apr 27
    , Date.fromCalendarDate 1784 Apr 11
    , Date.fromCalendarDate 1785 May 1
    , Date.fromCalendarDate 1786 Apr 23
    , Date.fromCalendarDate 1787 Apr 8
    , Date.fromCalendarDate 1788 Apr 27
    , Date.fromCalendarDate 1789 Apr 19
    , Date.fromCalendarDate 1790 Apr 4
    , Date.fromCalendarDate 1791 Apr 24
    , Date.fromCalendarDate 1792 Apr 15
    , Date.fromCalendarDate 1793 May 5
    , Date.fromCalendarDate 1794 Apr 20
    , Date.fromCalendarDate 1795 Apr 12
    , Date.fromCalendarDate 1796 May 1
    , Date.fromCalendarDate 1797 Apr 16
    , Date.fromCalendarDate 1798 Apr 8
    , Date.fromCalendarDate 1799 Apr 28
    , Date.fromCalendarDate 1800 Apr 20
    , Date.fromCalendarDate 1801 Apr 5
    , Date.fromCalendarDate 1802 Apr 25
    , Date.fromCalendarDate 1803 Apr 17
    , Date.fromCalendarDate 1804 May 6
    , Date.fromCalendarDate 1805 Apr 21
    , Date.fromCalendarDate 1806 Apr 13
    , Date.fromCalendarDate 1807 Apr 26
    , Date.fromCalendarDate 1808 Apr 17
    , Date.fromCalendarDate 1809 Apr 9
    , Date.fromCalendarDate 1810 Apr 29
    , Date.fromCalendarDate 1811 Apr 14
    , Date.fromCalendarDate 1812 May 3
    , Date.fromCalendarDate 1813 Apr 25
    , Date.fromCalendarDate 1814 Apr 10
    , Date.fromCalendarDate 1815 Apr 30
    , Date.fromCalendarDate 1816 Apr 21
    , Date.fromCalendarDate 1817 Apr 6
    , Date.fromCalendarDate 1818 Apr 26
    , Date.fromCalendarDate 1819 Apr 18
    , Date.fromCalendarDate 1820 Apr 9
    , Date.fromCalendarDate 1821 Apr 22
    , Date.fromCalendarDate 1822 Apr 14
    , Date.fromCalendarDate 1823 May 4
    , Date.fromCalendarDate 1824 Apr 18
    , Date.fromCalendarDate 1825 Apr 10
    , Date.fromCalendarDate 1826 Apr 30
    , Date.fromCalendarDate 1827 Apr 15
    , Date.fromCalendarDate 1828 Apr 6
    , Date.fromCalendarDate 1829 Apr 26
    , Date.fromCalendarDate 1830 Apr 18
    , Date.fromCalendarDate 1831 May 1
    , Date.fromCalendarDate 1832 Apr 22
    , Date.fromCalendarDate 1833 Apr 14
    , Date.fromCalendarDate 1834 May 4
    , Date.fromCalendarDate 1835 Apr 19
    , Date.fromCalendarDate 1836 Apr 10
    , Date.fromCalendarDate 1837 Apr 30
    , Date.fromCalendarDate 1838 Apr 15
    , Date.fromCalendarDate 1839 Apr 7
    , Date.fromCalendarDate 1840 Apr 26
    , Date.fromCalendarDate 1841 Apr 11
    , Date.fromCalendarDate 1842 May 1
    , Date.fromCalendarDate 1843 Apr 23
    , Date.fromCalendarDate 1844 Apr 7
    , Date.fromCalendarDate 1845 Apr 27
    , Date.fromCalendarDate 1846 Apr 19
    , Date.fromCalendarDate 1847 Apr 4
    , Date.fromCalendarDate 1848 Apr 23
    , Date.fromCalendarDate 1849 Apr 15
    , Date.fromCalendarDate 1850 May 5
    , Date.fromCalendarDate 1920 Apr 11
    , Date.fromCalendarDate 1921 May 1
    , Date.fromCalendarDate 1922 Apr 16
    , Date.fromCalendarDate 1923 Apr 8
    , Date.fromCalendarDate 1924 Apr 27
    , Date.fromCalendarDate 1925 Apr 19
    , Date.fromCalendarDate 1926 May 2
    , Date.fromCalendarDate 1927 Apr 24
    , Date.fromCalendarDate 1928 Apr 15
    , Date.fromCalendarDate 1929 May 5
    , Date.fromCalendarDate 1930 Apr 20
    , Date.fromCalendarDate 1931 Apr 12
    , Date.fromCalendarDate 1932 May 1
    , Date.fromCalendarDate 1933 Apr 16
    , Date.fromCalendarDate 1934 Apr 8
    , Date.fromCalendarDate 1935 Apr 28
    , Date.fromCalendarDate 1936 Apr 12
    , Date.fromCalendarDate 1937 May 2
    , Date.fromCalendarDate 1938 Apr 24
    , Date.fromCalendarDate 1939 Apr 9
    , Date.fromCalendarDate 1940 Apr 28
    , Date.fromCalendarDate 1941 Apr 20
    , Date.fromCalendarDate 1942 Apr 5
    , Date.fromCalendarDate 1943 Apr 25
    , Date.fromCalendarDate 1944 Apr 16
    , Date.fromCalendarDate 1945 May 6
    , Date.fromCalendarDate 1946 Apr 21
    , Date.fromCalendarDate 1947 Apr 13
    , Date.fromCalendarDate 1948 May 2
    , Date.fromCalendarDate 1949 Apr 24
    , Date.fromCalendarDate 1950 Apr 9
    , Date.fromCalendarDate 1951 Apr 29
    , Date.fromCalendarDate 1952 Apr 20
    , Date.fromCalendarDate 1953 Apr 5
    , Date.fromCalendarDate 1954 Apr 25
    , Date.fromCalendarDate 1955 Apr 17
    , Date.fromCalendarDate 1956 May 6
    , Date.fromCalendarDate 1957 Apr 21
    , Date.fromCalendarDate 1958 Apr 13
    , Date.fromCalendarDate 1959 May 3
    , Date.fromCalendarDate 1960 Apr 17
    , Date.fromCalendarDate 1961 Apr 9
    , Date.fromCalendarDate 1962 Apr 29
    , Date.fromCalendarDate 1963 Apr 14
    , Date.fromCalendarDate 1964 May 3
    , Date.fromCalendarDate 1965 Apr 25
    , Date.fromCalendarDate 1966 Apr 10
    , Date.fromCalendarDate 1967 Apr 30
    , Date.fromCalendarDate 1968 Apr 21
    , Date.fromCalendarDate 1969 Apr 13
    , Date.fromCalendarDate 1970 Apr 26
    , Date.fromCalendarDate 1971 Apr 18
    , Date.fromCalendarDate 1972 Apr 9
    , Date.fromCalendarDate 1973 Apr 29
    , Date.fromCalendarDate 1974 Apr 14
    , Date.fromCalendarDate 1975 May 4
    , Date.fromCalendarDate 1976 Apr 25
    , Date.fromCalendarDate 1977 Apr 10
    , Date.fromCalendarDate 1978 Apr 30
    , Date.fromCalendarDate 1979 Apr 22
    , Date.fromCalendarDate 1980 Apr 6
    , Date.fromCalendarDate 1981 Apr 26
    , Date.fromCalendarDate 1982 Apr 18
    , Date.fromCalendarDate 1983 May 8
    , Date.fromCalendarDate 1984 Apr 22
    , Date.fromCalendarDate 1985 Apr 14
    , Date.fromCalendarDate 1986 May 4
    , Date.fromCalendarDate 1987 Apr 19
    , Date.fromCalendarDate 1988 Apr 10
    , Date.fromCalendarDate 1989 Apr 30
    , Date.fromCalendarDate 1990 Apr 15
    , Date.fromCalendarDate 1991 Apr 7
    , Date.fromCalendarDate 1992 Apr 26
    , Date.fromCalendarDate 1993 Apr 18
    , Date.fromCalendarDate 1994 May 1
    , Date.fromCalendarDate 1995 Apr 23
    , Date.fromCalendarDate 1996 Apr 14
    , Date.fromCalendarDate 1997 Apr 27
    , Date.fromCalendarDate 1998 Apr 19
    , Date.fromCalendarDate 1999 Apr 11
    , Date.fromCalendarDate 2000 Apr 30
    , Date.fromCalendarDate 2001 Apr 15
    , Date.fromCalendarDate 2002 May 5
    , Date.fromCalendarDate 2003 Apr 27
    , Date.fromCalendarDate 2004 Apr 11
    , Date.fromCalendarDate 2005 May 1
    , Date.fromCalendarDate 2006 Apr 23
    , Date.fromCalendarDate 2007 Apr 8
    , Date.fromCalendarDate 2008 Apr 27
    , Date.fromCalendarDate 2009 Apr 19
    , Date.fromCalendarDate 2010 Apr 4
    , Date.fromCalendarDate 2011 Apr 24
    , Date.fromCalendarDate 2012 Apr 15
    , Date.fromCalendarDate 2013 May 5
    , Date.fromCalendarDate 2014 Apr 20
    , Date.fromCalendarDate 2015 Apr 12
    , Date.fromCalendarDate 2016 May 1
    , Date.fromCalendarDate 2017 Apr 16
    , Date.fromCalendarDate 2018 Apr 8
    , Date.fromCalendarDate 2019 Apr 28
    , Date.fromCalendarDate 2020 Apr 19
    , Date.fromCalendarDate 2021 May 2
    , Date.fromCalendarDate 2022 Apr 24
    , Date.fromCalendarDate 2023 Apr 16
    , Date.fromCalendarDate 2024 May 5
    , Date.fromCalendarDate 2025 Apr 20
    , Date.fromCalendarDate 2026 Apr 12
    , Date.fromCalendarDate 2027 May 2
    , Date.fromCalendarDate 2028 Apr 16
    , Date.fromCalendarDate 2029 Apr 8
    , Date.fromCalendarDate 2030 Apr 28
    , Date.fromCalendarDate 2031 Apr 13
    , Date.fromCalendarDate 2032 May 2
    , Date.fromCalendarDate 2033 Apr 24
    , Date.fromCalendarDate 2034 Apr 9
    , Date.fromCalendarDate 2035 Apr 29
    , Date.fromCalendarDate 2036 Apr 20
    , Date.fromCalendarDate 2037 Apr 5
    , Date.fromCalendarDate 2038 Apr 25
    , Date.fromCalendarDate 2039 Apr 17
    , Date.fromCalendarDate 2040 May 6
    , Date.fromCalendarDate 2041 Apr 21
    , Date.fromCalendarDate 2042 Apr 13
    , Date.fromCalendarDate 2043 May 3
    , Date.fromCalendarDate 2044 Apr 24
    , Date.fromCalendarDate 2045 Apr 9
    , Date.fromCalendarDate 2046 Apr 29
    , Date.fromCalendarDate 2047 Apr 21
    , Date.fromCalendarDate 2048 Apr 5
    , Date.fromCalendarDate 2049 Apr 25
    , Date.fromCalendarDate 2050 Apr 17
    , Date.fromCalendarDate 2051 May 7
    , Date.fromCalendarDate 2052 Apr 21
    , Date.fromCalendarDate 2053 Apr 13
    , Date.fromCalendarDate 2054 May 3
    , Date.fromCalendarDate 2055 Apr 18
    , Date.fromCalendarDate 2056 Apr 9
    , Date.fromCalendarDate 2057 Apr 29
    , Date.fromCalendarDate 2058 Apr 14
    , Date.fromCalendarDate 2059 May 4
    , Date.fromCalendarDate 2060 Apr 25
    , Date.fromCalendarDate 2061 Apr 10
    , Date.fromCalendarDate 2062 Apr 30
    , Date.fromCalendarDate 2063 Apr 22
    , Date.fromCalendarDate 2064 Apr 13
    , Date.fromCalendarDate 2065 Apr 26
    , Date.fromCalendarDate 2066 Apr 18
    , Date.fromCalendarDate 2067 Apr 10
    , Date.fromCalendarDate 2068 Apr 29
    , Date.fromCalendarDate 2069 Apr 14
    , Date.fromCalendarDate 2070 May 4
    , Date.fromCalendarDate 2071 Apr 19
    , Date.fromCalendarDate 2072 Apr 10
    , Date.fromCalendarDate 2073 Apr 30
    , Date.fromCalendarDate 2074 Apr 22
    , Date.fromCalendarDate 2075 Apr 7
    , Date.fromCalendarDate 2076 Apr 26
    , Date.fromCalendarDate 2077 Apr 18
    , Date.fromCalendarDate 2078 May 8
    , Date.fromCalendarDate 2079 Apr 23
    , Date.fromCalendarDate 2080 Apr 14
    , Date.fromCalendarDate 2081 May 4
    , Date.fromCalendarDate 2082 Apr 19
    , Date.fromCalendarDate 2083 Apr 11
    , Date.fromCalendarDate 2084 Apr 30
    , Date.fromCalendarDate 2085 Apr 15
    , Date.fromCalendarDate 2086 Apr 7
    , Date.fromCalendarDate 2087 Apr 27
    , Date.fromCalendarDate 2088 Apr 18
    , Date.fromCalendarDate 2089 May 1
    , Date.fromCalendarDate 2090 Apr 23
    , Date.fromCalendarDate 2091 Apr 8
    , Date.fromCalendarDate 2092 Apr 27
    , Date.fromCalendarDate 2093 Apr 19
    , Date.fromCalendarDate 2094 Apr 11
    , Date.fromCalendarDate 2095 Apr 24
    , Date.fromCalendarDate 2096 Apr 15
    , Date.fromCalendarDate 2097 May 5
    , Date.fromCalendarDate 2098 Apr 27
    , Date.fromCalendarDate 2099 Apr 12
    , Date.fromCalendarDate 2100 May 2 ]


westernEasters =
    [ Date.fromCalendarDate 1200 Apr 9
    , Date.fromCalendarDate 1201 Apr 1
    , Date.fromCalendarDate 1202 Apr 21
    , Date.fromCalendarDate 1203 Apr 6
    , Date.fromCalendarDate 1204 Mar 28
    , Date.fromCalendarDate 1205 Apr 17
    , Date.fromCalendarDate 1206 Apr 2
    , Date.fromCalendarDate 1207 Mar 25
    , Date.fromCalendarDate 1208 Apr 13
    , Date.fromCalendarDate 1209 Apr 5
    , Date.fromCalendarDate 1210 Apr 18
    , Date.fromCalendarDate 1211 Apr 10
    , Date.fromCalendarDate 1212 Apr 1
    , Date.fromCalendarDate 1213 Apr 21
    , Date.fromCalendarDate 1214 Apr 6
    , Date.fromCalendarDate 1215 Mar 29
    , Date.fromCalendarDate 1216 Apr 17
    , Date.fromCalendarDate 1217 Apr 2
    , Date.fromCalendarDate 1218 Apr 22
    , Date.fromCalendarDate 1219 Apr 14
    , Date.fromCalendarDate 1220 Mar 29
    , Date.fromCalendarDate 1221 Apr 18
    , Date.fromCalendarDate 1222 Apr 10
    , Date.fromCalendarDate 1223 Mar 26
    , Date.fromCalendarDate 1224 Apr 14
    , Date.fromCalendarDate 1225 Apr 6
    , Date.fromCalendarDate 1226 Mar 22
    , Date.fromCalendarDate 1227 Apr 11
    , Date.fromCalendarDate 1228 Apr 2
    , Date.fromCalendarDate 1229 Apr 22
    , Date.fromCalendarDate 1230 Apr 7
    , Date.fromCalendarDate 1231 Mar 30
    , Date.fromCalendarDate 1232 Apr 18
    , Date.fromCalendarDate 1233 Apr 10
    , Date.fromCalendarDate 1234 Mar 26
    , Date.fromCalendarDate 1235 Apr 15
    , Date.fromCalendarDate 1236 Apr 6
    , Date.fromCalendarDate 1237 Apr 19
    , Date.fromCalendarDate 1238 Apr 11
    , Date.fromCalendarDate 1239 Apr 3
    , Date.fromCalendarDate 1240 Apr 22
    , Date.fromCalendarDate 1241 Apr 7
    , Date.fromCalendarDate 1242 Mar 30
    , Date.fromCalendarDate 1243 Apr 19
    , Date.fromCalendarDate 1244 Apr 3
    , Date.fromCalendarDate 1245 Mar 26
    , Date.fromCalendarDate 1246 Apr 15
    , Date.fromCalendarDate 1247 Mar 31
    , Date.fromCalendarDate 1248 Apr 19
    , Date.fromCalendarDate 1249 Apr 11
    , Date.fromCalendarDate 1250 Mar 27
    , Date.fromCalendarDate 1251 Apr 16
    , Date.fromCalendarDate 1252 Apr 7
    , Date.fromCalendarDate 1253 Mar 30
    , Date.fromCalendarDate 1254 Apr 12
    , Date.fromCalendarDate 1255 Apr 4
    , Date.fromCalendarDate 1256 Apr 23
    , Date.fromCalendarDate 1257 Apr 8
    , Date.fromCalendarDate 1258 Mar 31
    , Date.fromCalendarDate 1259 Apr 20
    , Date.fromCalendarDate 1260 Apr 11
    , Date.fromCalendarDate 1261 Mar 27
    , Date.fromCalendarDate 1262 Apr 16
    , Date.fromCalendarDate 1263 Apr 8
    , Date.fromCalendarDate 1264 Mar 23
    , Date.fromCalendarDate 1265 Apr 12
    , Date.fromCalendarDate 1266 Apr 4
    , Date.fromCalendarDate 1267 Apr 24
    , Date.fromCalendarDate 1268 Apr 8
    , Date.fromCalendarDate 1269 Mar 31
    , Date.fromCalendarDate 1270 Apr 20
    , Date.fromCalendarDate 1271 Apr 5
    , Date.fromCalendarDate 1272 Mar 27
    , Date.fromCalendarDate 1273 Apr 16
    , Date.fromCalendarDate 1274 Apr 1
    , Date.fromCalendarDate 1275 Apr 21
    , Date.fromCalendarDate 1276 Apr 12
    , Date.fromCalendarDate 1277 Mar 28
    , Date.fromCalendarDate 1278 Apr 17
    , Date.fromCalendarDate 1279 Apr 9
    , Date.fromCalendarDate 1280 Mar 31
    , Date.fromCalendarDate 1281 Apr 13
    , Date.fromCalendarDate 1282 Apr 5
    , Date.fromCalendarDate 1283 Mar 28
    , Date.fromCalendarDate 1284 Apr 16
    , Date.fromCalendarDate 1285 Apr 1
    , Date.fromCalendarDate 1286 Apr 21
    , Date.fromCalendarDate 1287 Apr 13
    , Date.fromCalendarDate 1288 Mar 28
    , Date.fromCalendarDate 1289 Apr 17
    , Date.fromCalendarDate 1290 Apr 9
    , Date.fromCalendarDate 1291 Mar 25
    , Date.fromCalendarDate 1292 Apr 13
    , Date.fromCalendarDate 1293 Apr 5
    , Date.fromCalendarDate 1294 Apr 25
    , Date.fromCalendarDate 1295 Apr 10
    , Date.fromCalendarDate 1296 Apr 1
    , Date.fromCalendarDate 1297 Apr 21
    , Date.fromCalendarDate 1298 Apr 6
    , Date.fromCalendarDate 1299 Mar 29
    , Date.fromCalendarDate 1300 Apr 18
    , Date.fromCalendarDate 1700 Apr 11
    , Date.fromCalendarDate 1701 Mar 27
    , Date.fromCalendarDate 1702 Apr 16
    , Date.fromCalendarDate 1703 Apr 8
    , Date.fromCalendarDate 1704 Mar 23
    , Date.fromCalendarDate 1705 Apr 12
    , Date.fromCalendarDate 1706 Apr 4
    , Date.fromCalendarDate 1707 Apr 24
    , Date.fromCalendarDate 1708 Apr 8
    , Date.fromCalendarDate 1709 Mar 31
    , Date.fromCalendarDate 1710 Apr 20
    , Date.fromCalendarDate 1711 Apr 5
    , Date.fromCalendarDate 1712 Mar 27
    , Date.fromCalendarDate 1713 Apr 16
    , Date.fromCalendarDate 1714 Apr 1
    , Date.fromCalendarDate 1715 Apr 21
    , Date.fromCalendarDate 1716 Apr 12
    , Date.fromCalendarDate 1717 Mar 28
    , Date.fromCalendarDate 1718 Apr 17
    , Date.fromCalendarDate 1719 Apr 9
    , Date.fromCalendarDate 1720 Mar 31
    , Date.fromCalendarDate 1721 Apr 13
    , Date.fromCalendarDate 1722 Apr 5
    , Date.fromCalendarDate 1723 Mar 28
    , Date.fromCalendarDate 1724 Apr 16
    , Date.fromCalendarDate 1725 Apr 1
    , Date.fromCalendarDate 1726 Apr 21
    , Date.fromCalendarDate 1727 Apr 13
    , Date.fromCalendarDate 1728 Mar 28
    , Date.fromCalendarDate 1729 Apr 17
    , Date.fromCalendarDate 1730 Apr 9
    , Date.fromCalendarDate 1731 Mar 25
    , Date.fromCalendarDate 1732 Apr 13
    , Date.fromCalendarDate 1733 Apr 5
    , Date.fromCalendarDate 1734 Apr 25
    , Date.fromCalendarDate 1735 Apr 10
    , Date.fromCalendarDate 1736 Apr 1
    , Date.fromCalendarDate 1737 Apr 21
    , Date.fromCalendarDate 1738 Apr 6
    , Date.fromCalendarDate 1739 Mar 29
    , Date.fromCalendarDate 1740 Apr 17
    , Date.fromCalendarDate 1741 Apr 2
    , Date.fromCalendarDate 1742 Mar 25
    , Date.fromCalendarDate 1743 Apr 14
    , Date.fromCalendarDate 1744 Apr 5
    , Date.fromCalendarDate 1745 Apr 18
    , Date.fromCalendarDate 1746 Apr 10
    , Date.fromCalendarDate 1747 Apr 2
    , Date.fromCalendarDate 1748 Apr 14
    , Date.fromCalendarDate 1749 Apr 6
    , Date.fromCalendarDate 1750 Mar 29
    , Date.fromCalendarDate 1751 Apr 11
    , Date.fromCalendarDate 1752 Apr 2
    , Date.fromCalendarDate 1753 Apr 22
    , Date.fromCalendarDate 1754 Apr 14
    , Date.fromCalendarDate 1755 Mar 30
    , Date.fromCalendarDate 1756 Apr 18
    , Date.fromCalendarDate 1757 Apr 10
    , Date.fromCalendarDate 1758 Mar 26
    , Date.fromCalendarDate 1759 Apr 15
    , Date.fromCalendarDate 1760 Apr 6
    , Date.fromCalendarDate 1761 Mar 22
    , Date.fromCalendarDate 1762 Apr 11
    , Date.fromCalendarDate 1763 Apr 3
    , Date.fromCalendarDate 1764 Apr 22
    , Date.fromCalendarDate 1765 Apr 7
    , Date.fromCalendarDate 1766 Mar 30
    , Date.fromCalendarDate 1767 Apr 19
    , Date.fromCalendarDate 1768 Apr 3
    , Date.fromCalendarDate 1769 Mar 26
    , Date.fromCalendarDate 1770 Apr 15
    , Date.fromCalendarDate 1771 Mar 31
    , Date.fromCalendarDate 1772 Apr 19
    , Date.fromCalendarDate 1773 Apr 11
    , Date.fromCalendarDate 1774 Apr 3
    , Date.fromCalendarDate 1775 Apr 16
    , Date.fromCalendarDate 1776 Apr 7
    , Date.fromCalendarDate 1777 Mar 30
    , Date.fromCalendarDate 1778 Apr 19
    , Date.fromCalendarDate 1779 Apr 4
    , Date.fromCalendarDate 1780 Mar 26
    , Date.fromCalendarDate 1781 Apr 15
    , Date.fromCalendarDate 1782 Mar 31
    , Date.fromCalendarDate 1783 Apr 20
    , Date.fromCalendarDate 1784 Apr 11
    , Date.fromCalendarDate 1785 Mar 27
    , Date.fromCalendarDate 1786 Apr 16
    , Date.fromCalendarDate 1787 Apr 8
    , Date.fromCalendarDate 1788 Mar 23
    , Date.fromCalendarDate 1789 Apr 12
    , Date.fromCalendarDate 1790 Apr 4
    , Date.fromCalendarDate 1791 Apr 24
    , Date.fromCalendarDate 1792 Apr 8
    , Date.fromCalendarDate 1793 Mar 31
    , Date.fromCalendarDate 1794 Apr 20
    , Date.fromCalendarDate 1795 Apr 5
    , Date.fromCalendarDate 1796 Mar 27
    , Date.fromCalendarDate 1797 Apr 16
    , Date.fromCalendarDate 1798 Apr 8
    , Date.fromCalendarDate 1799 Mar 24
    , Date.fromCalendarDate 1800 Apr 13
    , Date.fromCalendarDate 1801 Apr 5
    , Date.fromCalendarDate 1802 Apr 18
    , Date.fromCalendarDate 1803 Apr 10
    , Date.fromCalendarDate 1804 Apr 1
    , Date.fromCalendarDate 1805 Apr 14
    , Date.fromCalendarDate 1806 Apr 6
    , Date.fromCalendarDate 1807 Mar 29
    , Date.fromCalendarDate 1808 Apr 17
    , Date.fromCalendarDate 1809 Apr 2
    , Date.fromCalendarDate 1810 Apr 22
    , Date.fromCalendarDate 1811 Apr 14
    , Date.fromCalendarDate 1812 Mar 29
    , Date.fromCalendarDate 1813 Apr 18
    , Date.fromCalendarDate 1814 Apr 10
    , Date.fromCalendarDate 1815 Mar 26
    , Date.fromCalendarDate 1816 Apr 14
    , Date.fromCalendarDate 1817 Apr 6
    , Date.fromCalendarDate 1818 Mar 22
    , Date.fromCalendarDate 1819 Apr 11
    , Date.fromCalendarDate 1820 Apr 2
    , Date.fromCalendarDate 1821 Apr 22
    , Date.fromCalendarDate 1822 Apr 7
    , Date.fromCalendarDate 1823 Mar 30
    , Date.fromCalendarDate 1824 Apr 18
    , Date.fromCalendarDate 1825 Apr 3
    , Date.fromCalendarDate 1826 Mar 26
    , Date.fromCalendarDate 1827 Apr 15
    , Date.fromCalendarDate 1828 Apr 6
    , Date.fromCalendarDate 1829 Apr 19
    , Date.fromCalendarDate 1830 Apr 11
    , Date.fromCalendarDate 1831 Apr 3
    , Date.fromCalendarDate 1832 Apr 22
    , Date.fromCalendarDate 1833 Apr 7
    , Date.fromCalendarDate 1834 Mar 30
    , Date.fromCalendarDate 1835 Apr 19
    , Date.fromCalendarDate 1836 Apr 3
    , Date.fromCalendarDate 1837 Mar 26
    , Date.fromCalendarDate 1838 Apr 15
    , Date.fromCalendarDate 1839 Mar 31
    , Date.fromCalendarDate 1840 Apr 19
    , Date.fromCalendarDate 1841 Apr 11
    , Date.fromCalendarDate 1842 Mar 27
    , Date.fromCalendarDate 1843 Apr 16
    , Date.fromCalendarDate 1844 Apr 7
    , Date.fromCalendarDate 1845 Mar 23
    , Date.fromCalendarDate 1846 Apr 12
    , Date.fromCalendarDate 1847 Apr 4
    , Date.fromCalendarDate 1848 Apr 23
    , Date.fromCalendarDate 1849 Apr 8
    , Date.fromCalendarDate 1850 Mar 31
    , Date.fromCalendarDate 1920 Apr 4
    , Date.fromCalendarDate 1921 Mar 27
    , Date.fromCalendarDate 1922 Apr 16
    , Date.fromCalendarDate 1923 Apr 1
    , Date.fromCalendarDate 1924 Apr 20
    , Date.fromCalendarDate 1925 Apr 12
    , Date.fromCalendarDate 1926 Apr 4
    , Date.fromCalendarDate 1927 Apr 17
    , Date.fromCalendarDate 1928 Apr 8
    , Date.fromCalendarDate 1929 Mar 31
    , Date.fromCalendarDate 1930 Apr 20
    , Date.fromCalendarDate 1931 Apr 5
    , Date.fromCalendarDate 1932 Mar 27
    , Date.fromCalendarDate 1933 Apr 16
    , Date.fromCalendarDate 1934 Apr 1
    , Date.fromCalendarDate 1935 Apr 21
    , Date.fromCalendarDate 1936 Apr 12
    , Date.fromCalendarDate 1937 Mar 28
    , Date.fromCalendarDate 1938 Apr 17
    , Date.fromCalendarDate 1939 Apr 9
    , Date.fromCalendarDate 1940 Mar 24
    , Date.fromCalendarDate 1941 Apr 13
    , Date.fromCalendarDate 1942 Apr 5
    , Date.fromCalendarDate 1943 Apr 25
    , Date.fromCalendarDate 1944 Apr 9
    , Date.fromCalendarDate 1945 Apr 1
    , Date.fromCalendarDate 1946 Apr 21
    , Date.fromCalendarDate 1947 Apr 6
    , Date.fromCalendarDate 1948 Mar 28
    , Date.fromCalendarDate 1949 Apr 17
    , Date.fromCalendarDate 1950 Apr 9
    , Date.fromCalendarDate 1951 Mar 25
    , Date.fromCalendarDate 1952 Apr 13
    , Date.fromCalendarDate 1953 Apr 5
    , Date.fromCalendarDate 1954 Apr 18
    , Date.fromCalendarDate 1955 Apr 10
    , Date.fromCalendarDate 1956 Apr 1
    , Date.fromCalendarDate 1957 Apr 21
    , Date.fromCalendarDate 1958 Apr 6
    , Date.fromCalendarDate 1959 Mar 29
    , Date.fromCalendarDate 1960 Apr 17
    , Date.fromCalendarDate 1961 Apr 2
    , Date.fromCalendarDate 1962 Apr 22
    , Date.fromCalendarDate 1963 Apr 14
    , Date.fromCalendarDate 1964 Mar 29
    , Date.fromCalendarDate 1965 Apr 18
    , Date.fromCalendarDate 1966 Apr 10
    , Date.fromCalendarDate 1967 Mar 26
    , Date.fromCalendarDate 1968 Apr 14
    , Date.fromCalendarDate 1969 Apr 6
    , Date.fromCalendarDate 1970 Mar 29
    , Date.fromCalendarDate 1971 Apr 11
    , Date.fromCalendarDate 1972 Apr 2
    , Date.fromCalendarDate 1973 Apr 22
    , Date.fromCalendarDate 1974 Apr 14
    , Date.fromCalendarDate 1975 Mar 30
    , Date.fromCalendarDate 1976 Apr 18
    , Date.fromCalendarDate 1977 Apr 10
    , Date.fromCalendarDate 1978 Mar 26
    , Date.fromCalendarDate 1979 Apr 15
    , Date.fromCalendarDate 1980 Apr 6
    , Date.fromCalendarDate 1981 Apr 19
    , Date.fromCalendarDate 1982 Apr 11
    , Date.fromCalendarDate 1983 Apr 3
    , Date.fromCalendarDate 1984 Apr 22
    , Date.fromCalendarDate 1985 Apr 7
    , Date.fromCalendarDate 1986 Mar 30
    , Date.fromCalendarDate 1987 Apr 19
    , Date.fromCalendarDate 1988 Apr 3
    , Date.fromCalendarDate 1989 Mar 26
    , Date.fromCalendarDate 1990 Apr 15
    , Date.fromCalendarDate 1991 Mar 31
    , Date.fromCalendarDate 1992 Apr 19
    , Date.fromCalendarDate 1993 Apr 11
    , Date.fromCalendarDate 1994 Apr 3
    , Date.fromCalendarDate 1995 Apr 16
    , Date.fromCalendarDate 1996 Apr 7
    , Date.fromCalendarDate 1997 Mar 30
    , Date.fromCalendarDate 1998 Apr 12
    , Date.fromCalendarDate 1999 Apr 4
    , Date.fromCalendarDate 2000 Apr 23
    , Date.fromCalendarDate 2001 Apr 15
    , Date.fromCalendarDate 2002 Mar 31
    , Date.fromCalendarDate 2003 Apr 20
    , Date.fromCalendarDate 2004 Apr 11
    , Date.fromCalendarDate 2005 Mar 27
    , Date.fromCalendarDate 2006 Apr 16
    , Date.fromCalendarDate 2007 Apr 8
    , Date.fromCalendarDate 2008 Mar 23
    , Date.fromCalendarDate 2009 Apr 12
    , Date.fromCalendarDate 2010 Apr 4
    , Date.fromCalendarDate 2011 Apr 24
    , Date.fromCalendarDate 2012 Apr 8
    , Date.fromCalendarDate 2013 Mar 31
    , Date.fromCalendarDate 2014 Apr 20
    , Date.fromCalendarDate 2015 Apr 5
    , Date.fromCalendarDate 2016 Mar 27
    , Date.fromCalendarDate 2017 Apr 16
    , Date.fromCalendarDate 2018 Apr 1
    , Date.fromCalendarDate 2019 Apr 21
    , Date.fromCalendarDate 2020 Apr 12
    , Date.fromCalendarDate 2021 Apr 4
    , Date.fromCalendarDate 2022 Apr 17
    , Date.fromCalendarDate 2023 Apr 9
    , Date.fromCalendarDate 2024 Mar 31
    , Date.fromCalendarDate 2025 Apr 20
    , Date.fromCalendarDate 2026 Apr 5
    , Date.fromCalendarDate 2027 Mar 28
    , Date.fromCalendarDate 2028 Apr 16
    , Date.fromCalendarDate 2029 Apr 1
    , Date.fromCalendarDate 2030 Apr 21
    , Date.fromCalendarDate 2031 Apr 13
    , Date.fromCalendarDate 2032 Mar 28
    , Date.fromCalendarDate 2033 Apr 17
    , Date.fromCalendarDate 2034 Apr 9
    , Date.fromCalendarDate 2035 Mar 25
    , Date.fromCalendarDate 2036 Apr 13
    , Date.fromCalendarDate 2037 Apr 5
    , Date.fromCalendarDate 2038 Apr 25
    , Date.fromCalendarDate 2039 Apr 10
    , Date.fromCalendarDate 2040 Apr 1
    , Date.fromCalendarDate 2041 Apr 21
    , Date.fromCalendarDate 2042 Apr 6
    , Date.fromCalendarDate 2043 Mar 29
    , Date.fromCalendarDate 2044 Apr 17
    , Date.fromCalendarDate 2045 Apr 9
    , Date.fromCalendarDate 2046 Mar 25
    , Date.fromCalendarDate 2047 Apr 14
    , Date.fromCalendarDate 2048 Apr 5
    , Date.fromCalendarDate 2049 Apr 18
    , Date.fromCalendarDate 2050 Apr 10
    , Date.fromCalendarDate 2051 Apr 2
    , Date.fromCalendarDate 2052 Apr 21
    , Date.fromCalendarDate 2053 Apr 6
    , Date.fromCalendarDate 2054 Mar 29
    , Date.fromCalendarDate 2055 Apr 18
    , Date.fromCalendarDate 2056 Apr 2
    , Date.fromCalendarDate 2057 Apr 22
    , Date.fromCalendarDate 2058 Apr 14
    , Date.fromCalendarDate 2059 Mar 30
    , Date.fromCalendarDate 2060 Apr 18
    , Date.fromCalendarDate 2061 Apr 10
    , Date.fromCalendarDate 2062 Mar 26
    , Date.fromCalendarDate 2063 Apr 15
    , Date.fromCalendarDate 2064 Apr 6
    , Date.fromCalendarDate 2065 Mar 29
    , Date.fromCalendarDate 2066 Apr 11
    , Date.fromCalendarDate 2067 Apr 3
    , Date.fromCalendarDate 2068 Apr 22
    , Date.fromCalendarDate 2069 Apr 14
    , Date.fromCalendarDate 2070 Mar 30
    , Date.fromCalendarDate 2071 Apr 19
    , Date.fromCalendarDate 2072 Apr 10
    , Date.fromCalendarDate 2073 Mar 26
    , Date.fromCalendarDate 2074 Apr 15
    , Date.fromCalendarDate 2075 Apr 7
    , Date.fromCalendarDate 2076 Apr 19
    , Date.fromCalendarDate 2077 Apr 11
    , Date.fromCalendarDate 2078 Apr 3
    , Date.fromCalendarDate 2079 Apr 23
    , Date.fromCalendarDate 2080 Apr 7
    , Date.fromCalendarDate 2081 Mar 30
    , Date.fromCalendarDate 2082 Apr 19
    , Date.fromCalendarDate 2083 Apr 4
    , Date.fromCalendarDate 2084 Mar 26
    , Date.fromCalendarDate 2085 Apr 15
    , Date.fromCalendarDate 2086 Mar 31
    , Date.fromCalendarDate 2087 Apr 20
    , Date.fromCalendarDate 2088 Apr 11
    , Date.fromCalendarDate 2089 Apr 3
    , Date.fromCalendarDate 2090 Apr 16
    , Date.fromCalendarDate 2091 Apr 8
    , Date.fromCalendarDate 2092 Mar 30
    , Date.fromCalendarDate 2093 Apr 12
    , Date.fromCalendarDate 2094 Apr 4
    , Date.fromCalendarDate 2095 Apr 24
    , Date.fromCalendarDate 2096 Apr 15
    , Date.fromCalendarDate 2097 Mar 31
    , Date.fromCalendarDate 2098 Apr 20
    , Date.fromCalendarDate 2099 Apr 12
    , Date.fromCalendarDate 2100 Mar 28 ]


